@@ -2,26 +2,26 @@
 
 (libtoolize --version) < /dev/null > /dev/null 2>&1 || {
 	echo;
-	echo "You must have libtool installed to compile StarDict";
+	echo "You must have libtool installed to compile Stardict";
 	echo;
 	exit;
 }
 
 (automake --version) < /dev/null > /dev/null 2>&1 || {
 	echo;
-	echo "You must have automake installed to compile StarDict";
+	echo "You must have automake installed to compile Stardict";
 	echo;
 	exit;
 }
 
 (autoconf --version) < /dev/null > /dev/null 2>&1 || {
 	echo;
-	echo "You must have autoconf installed to compile StarDict";
+	echo "You must have autoconf installed to compile Stardict";
 	echo;
 	exit;
 }
 
-echo "Generating configuration files for StarDict, please wait...."
+echo "Generating configuration files for Stardict, please wait...."
 echo;
 
 echo "Running libtoolize, please ignore non-fatal messages...."
@@ -37,4 +37,4 @@ echo "Running autoconf ...."
 autoconf || exit;
 echo "Running automake ...."
 automake || exit;
-#./configure --prefix=/usr --sysconfdir=/etc  --mandir=/usr/share/man --disable-gnome-support $@
+#./configure --prefix=/usr --sysconfdir=/etc  --mandir=/usr/share/man $@
