@@ -1,6 +1,6 @@
 /*
  * This file part of StarDict - A international dictionary for GNOME.
- * http://stardict.sourceforge.net
+ * http://stardict-4.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -180,9 +180,14 @@ inline const gchar *offset_index::read_first_on_page_key(glong page_idx)
 	fseek(idxfile, oft_file.wordoffset[page_idx], SEEK_SET);
 	guint32 page_size=oft_file.wordoffset[page_idx+1]-oft_file.wordoffset[page_idx];
 	gulong minsize = sizeof(wordentry_buf);
-	if (page_size < minsize)
+	if (page_size < minsize) {
 		minsize = page_size;
-	fread(wordentry_buf, minsize, 1, idxfile); //TODO: check returned values, deal with word entry that strlen>255.
+	}
+	size_t fread_size;
+	fread_size = fread(wordentry_buf, minsize, 1, idxfile); //TODO: check returned values, deal with word entry that strlen>255.
+	if (fread_size != 1) {
+		g_print("fread error!\n");
+	}
 	return wordentry_buf;
 }
 
@@ -591,7 +596,11 @@ inline gulong offset_index::load_page(glong page_idx)
 	if (page_idx!=page.idx) {
 		page_data.resize(oft_file.wordoffset[page_idx+1]-oft_file.wordoffset[page_idx]);
 		fseek(idxfile, oft_file.wordoffset[page_idx], SEEK_SET);
-		fread(&page_data[0], 1, page_data.size(), idxfile);
+		size_t fread_size;
+		fread_size = fread(&page_data[0], page_data.size(), 1, idxfile);
+		if (fread_size != 1) {
+			g_print("fread error!\n");
+		}
 		page.fill(&page_data[0], nentr, page_idx);
 	}
 
@@ -812,9 +821,14 @@ inline const gchar *synonym_file::read_first_on_page_key(glong page_idx)
 	fseek(synfile, oft_file.wordoffset[page_idx], SEEK_SET);
 	guint32 page_size=oft_file.wordoffset[page_idx+1]-oft_file.wordoffset[page_idx];
 	gulong minsize = sizeof(wordentry_buf);
-        if (page_size < minsize)
-                minsize = page_size;
-	fread(wordentry_buf, minsize, 1, synfile); //TODO: check returned values, deal with word entry that strlen>255.
+	if (page_size < minsize) {
+		minsize = page_size;
+	}
+	size_t fread_size;
+	fread_size = fread(wordentry_buf, minsize, 1, synfile); //TODO: check returned values, deal with word entry that strlen>255.
+	if (fread_size != 1) {
+		g_print("fread error!\n");
+	}
 	return wordentry_buf;
 }
 
@@ -910,7 +924,11 @@ inline gulong synonym_file::load_page(glong page_idx)
 	if (page_idx!=page.idx) {
 		page_data.resize(oft_file.wordoffset[page_idx+1]-oft_file.wordoffset[page_idx]);
 		fseek(synfile, oft_file.wordoffset[page_idx], SEEK_SET);
-		fread(&page_data[0], 1, page_data.size(), synfile);
+		size_t fread_size;
+		fread_size = fread(&page_data[0], page_data.size(), 1, synfile);
+		if (fread_size != 1) {
+			g_print("fread error!\n");
+		}
 		page.fill(&page_data[0], nentr, page_idx);
 	}
 
