@@ -1,6 +1,6 @@
 /* 
  * This file part of StarDict - A international dictionary for GNOME.
- * http://stardict.sourceforge.net
+ * http://stardict-4.sourceforge.net
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #ifdef _WIN32
-#define VERSION "2.4.8.1"
+#define VERSION "2.4.9"
 #  include <gdk/gdkwin32.h>
 #endif
 
@@ -82,7 +82,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(ClearCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,3);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Clear the search box"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Clear the search box"));
 #endif
 	
 	WordCombo = gtk_combo_new();
@@ -108,7 +108,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(GoCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Fuzzy Query"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Fuzzy Query"));
 #endif
 
 	button=gtk_button_new();
@@ -120,7 +120,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"button_press_event", G_CALLBACK(on_back_button_press),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Go Back - Right button: history (Alt+Left)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Go Back - Right button: history (Alt+Left)"));
 
 	button=gtk_button_new();	
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_GO_BACK,GTK_ICON_SIZE_BUTTON));
@@ -130,7 +130,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(PreviousCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Previous word (Alt+Up)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Previous word (Alt+Up)"));
 
 	button=gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD,GTK_ICON_SIZE_BUTTON));
@@ -140,7 +140,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(NextCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Next word (Alt+Down)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Next word (Alt+Down)"));
 
 	button=gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_HOME,GTK_ICON_SIZE_BUTTON));
@@ -150,7 +150,7 @@ void TopWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(MenuCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);	
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Show the main menu (Alt+M)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Show the main menu (Alt+M)"));
 }
 
 void TopWin::Destroy(void)
@@ -454,7 +454,7 @@ void TopWin::on_main_menu_dictmanage_activate(GtkMenuItem *menuitem, TopWin *oTo
 
 void TopWin::on_main_menu_newversion_activate(GtkMenuItem *menuitem, TopWin *oTopWin)
 {
-  show_url("http://stardict.sourceforge.net");
+  show_url("http://stardict-4.sourceforge.net");
 }
 
 void TopWin::on_main_menu_help_activate(GtkMenuItem *menuitem, TopWin *oTopWin)
@@ -465,16 +465,16 @@ void TopWin::on_main_menu_help_activate(GtkMenuItem *menuitem, TopWin *oTopWin)
 void TopWin::on_main_menu_about_activate(GtkMenuItem *menuitem, TopWin *oTopWin)
 {
 	const gchar *authors[] = {
-    "Hu Zheng <huzheng_001@163.com>",
+    "Hu Zheng <huzheng001@gmail.com>",
     "Evgeniy <dushistov@mail.ru>",
     "Opera Wang <wangvisual@sohu.com>",
     "Ma Su'an <msa@wri.com.cn>",
         NULL
     };
-    gchar *documenters[] = {
-		(gchar *)"Hu Zheng <huzheng_001@163.com>",
-		(gchar *)"Will Robinson <wsr23@stanford.edu>",
-		(gchar *)"Anthony Fok <foka@debian.org>",
+    const gchar *documenters[] = {
+		"Hu Zheng <huzheng001@gmail.com>",
+		"Will Robinson <wsr23@stanford.edu>",
+		"Anthony Fok <foka@debian.org>",
 	    NULL
     };
     gchar *translator_credits = _("translator_credits");
@@ -482,9 +482,9 @@ void TopWin::on_main_menu_about_activate(GtkMenuItem *menuitem, TopWin *oTopWin)
 	gtk_show_about_dialog(GTK_WINDOW (gpAppFrame->window),
 		"name", _("StarDict"),
 		"version", VERSION,
-		"website", "http://stardict.sourceforge.net",
+		"website", "http://stardict-4.sourceforge.net",
 		"comments", _("StarDict is an international dictionary for GNOME."),
-		"copyright", "Copyright \xc2\xa9 1999 by Ma Su'an\n" "Copyright \xc2\xa9 2002 by Opera Wang\n" "Copyright \xc2\xa9 2003-2006 by Hu Zheng",
+		"copyright", "Copyright \xc2\xa9 1999 by Ma Su'an\n" "Copyright \xc2\xa9 2002 by Opera Wang\n" "Copyright \xc2\xa9 2003-2006 by Hu Zheng\n" "Copyright \xc2\xa9 2021 by Hu Zheng",
 		"authors", (const char **)authors,
 		"documenters", (const char **)documenters,
 		"translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -656,7 +656,7 @@ void TopWin::InsertHisList(const gchar *word)
 
 void TopWin::SaveHistory()
 {
-	FILE *f=g_fopen(conf->get_string("/apps/stardict/preferences/dictionary/history").c_str(), "w");
+	FILE *f=g_fopen(conf->get_string("/apps/stardict/preferences/dictionary/history").c_str(), "wb");
 	if (!f)
 		return;
 	GList *hist_list = HisList;
@@ -674,7 +674,7 @@ void TopWin::LoadHistory()
 	if (g_stat (filename, &stats) == -1)
         	return;
 	FILE *historyfile;
-	historyfile = g_fopen(filename,"r");
+	historyfile = g_fopen(filename,"rb");
 	if (!historyfile)
 		return;
 	gchar *buffer = (gchar *)g_malloc (stats.st_size + 1);
@@ -1209,7 +1209,7 @@ void ToolWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),ShowListButton,false,false,5);
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,ShowListButton,_("Show the word list"),NULL);
+	gtk_widget_set_tooltip_text(ShowListButton,_("Show the word list"));
 	
 	HideListButton=gtk_button_new();	
 	image = gtk_image_new_from_stock(GTK_STOCK_GOTO_FIRST,GTK_ICON_SIZE_SMALL_TOOLBAR);
@@ -1224,7 +1224,7 @@ void ToolWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),HideListButton,false,false,5);
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips, HideListButton,_("Hide the word list"),NULL);
+	gtk_widget_set_tooltip_text(HideListButton,_("Hide the word list"));
 
 
 	if (conf->get_bool("/apps/stardict/preferences/main_window/hide_list"))
@@ -1242,7 +1242,7 @@ void ToolWin::Create(GtkWidget *vbox)
 	GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(CopyCallback),this);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,5);	
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Copy"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Copy"));
 #endif
 
 	PronounceWordButton=gtk_button_new();
@@ -1256,7 +1256,7 @@ void ToolWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),PronounceWordButton,false,false,5);	
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,PronounceWordButton,_("Pronounce the word"),NULL);	
+	gtk_widget_set_tooltip_text(PronounceWordButton,_("Pronounce the word"));	
 	gtk_widget_set_sensitive(PronounceWordButton, false);
 
 	button=gtk_button_new();	
@@ -1270,7 +1270,7 @@ void ToolWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,5);
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Save to file(Alt+E)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Save to file(Alt+E)"));
 	
 #ifndef CONFIG_GPE
 	button=gtk_button_new();	
@@ -1280,7 +1280,7 @@ void ToolWin::Create(GtkWidget *vbox)
 	GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(PrintCallback),this);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,5);	
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Print"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Print"));
 	gtk_widget_set_sensitive(button, false);
 #endif
 
@@ -1295,7 +1295,7 @@ void ToolWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,5);	
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Search in the definition (Ctrl+F)"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Search in the definition (Ctrl+F)"));
 }
 
 void ToolWin::ShowListCallback(GtkWidget *widget, gpointer data)
@@ -1420,7 +1420,7 @@ gboolean TextWin::OnSearchKeyPress(GtkWidget *widget, GdkEventKey *event,
 void TextWin::OnFindSearchPanel(GtkWidget *widget, TextWin *oTextWin)
 {
 	const gchar *text=gtk_entry_get_text(oTextWin->eSearch);
-	if (text && (*text)) {
+	if (text && *text) {
 		if (oTextWin->Find(text, oTextWin->search_from_beginning)) {
 			oTextWin->search_from_beginning = FALSE;
 			oTextWin->find_text = text;
@@ -1478,7 +1478,7 @@ void TextWin::Create(GtkWidget *vbox)
 
 void TextWin::ShowInitFailed()
 {
-	Show(_("Warning! No dictionary is loaded.\nPlease go to StarDict's website and download some dictionaries:\nhttp://stardict.sourceforge.net"));
+	Show(_("Warning! No dictionary is loaded.\nPlease go to StarDict's website and download some dictionaries:\nhttp://stardict-4.sourceforge.net"));
 }
 
 void TextWin::ShowTips()
@@ -1718,7 +1718,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(ScanSelectionCheckButton), "toggled", 
 									 G_CALLBACK(ScanCallback), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),ScanSelectionCheckButton,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,ScanSelectionCheckButton,_("Scan the selection"),NULL);
+	gtk_widget_set_tooltip_text(ScanSelectionCheckButton,_("Scan the selection"));
 
 	GtkWidget *button = gtk_button_new();	
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO,GTK_ICON_SIZE_SMALL_TOOLBAR));
@@ -1732,7 +1732,7 @@ void BottomWin::Create(GtkWidget *vbox)
 #else
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,8);
 #endif
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Show info"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Show info"));
 
 	button=gtk_button_new();	
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_QUIT,GTK_ICON_SIZE_SMALL_TOOLBAR));
@@ -1742,7 +1742,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(QuitCallback), NULL);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Quit"), NULL);
+	gtk_widget_set_tooltip_text(button,_("Quit"));
 
 
 	// the next buttons will be pack from right to left.	
@@ -1755,7 +1755,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(PreferenceCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Preferences"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Preferences"));
 
 	button=gtk_button_new();	
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_PROPERTIES,GTK_ICON_SIZE_SMALL_TOOLBAR));
@@ -1765,7 +1765,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(DictManageCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Manage dictionaries"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Manage dictionaries"));
 
 	button=gtk_button_new();	
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_INDEX,GTK_ICON_SIZE_SMALL_TOOLBAR));
@@ -1775,7 +1775,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(NewVersionCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Go to the StarDict website"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Go to the StarDict website"));
 #endif
 
 	button=gtk_button_new();	
@@ -1787,7 +1787,7 @@ void BottomWin::Create(GtkWidget *vbox)
 	g_signal_connect(G_OBJECT(button),"button_press_event", G_CALLBACK(on_internetsearch_button_press),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Search an Internet dictionary - Right button: website list"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Search an Internet dictionary - Right button: website list"));
 }
 
 void BottomWin::ScanCallback(GtkToggleButton *button, gpointer data)
@@ -1888,7 +1888,7 @@ void BottomWin::InternetSearchCallback(GtkButton *button, BottomWin *oBottomWin)
 #ifndef CONFIG_GPE
 void BottomWin::NewVersionCallback(GtkButton *button, BottomWin *oBottomWin)
 {
-  show_url("http://stardict.sourceforge.net");
+  show_url("http://stardict-4.sourceforge.net");
 }
 
 void BottomWin::DictManageCallback(GtkButton *button, BottomWin *oBottomWin)
