@@ -1,6 +1,6 @@
 /* StarDict - A international dictionary for GNOME.
- * http://stardict.sourceforge.net
- * Copyright (C) 2003-2006 HuZheng <huzheng_001@163.com>
+ * http://stardict-4.sourceforge.net
+ * Copyright (C) 2003-2006 HuZheng <huzheng001@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Modified by the StarDict Team and others 2003-2006.  See the AUTHORS
  * file for a list of people on the StarDict Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * StarDict at http://stardict.sourceforge.net.
+ * StarDict at http://stardict-4.sourceforge.net.
  */
 
 
@@ -178,7 +178,7 @@ void AppCore::Create(gchar *queryword)
 	g_signal_connect (G_OBJECT (window), "key_press_event", G_CALLBACK (vKeyPressReleaseCallback), this);
 	g_signal_connect (G_OBJECT (window), "key_release_event", G_CALLBACK (vKeyPressReleaseCallback), this);
 
-	tooltips = gtk_tooltips_new ();
+	//tooltips = gtk_tooltips_new ();
 
 	GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
